pub struct ViennaRNA { /* private fields */ }Expand description
The union of different parameterizations, may contain redundant fallback parameters.
Implementations
Sourceimpl ViennaRNA
impl ViennaRNA
Sourcepub fn from_andrunescu_params(params: &'static AndronescuParams) -> Self
pub fn from_andrunescu_params(params: &'static AndronescuParams) -> Self
Initializes a model from fitted parameters, which means there is no possiblity to change the temperature.
Sourcepub fn from_thermo_params(
params: &'static RNAThermoParams,
celsius: f64,
) -> Self
pub fn from_thermo_params( params: &'static RNAThermoParams, celsius: f64, ) -> Self
Initializes a model from thermodynamic parameters. That’s the default!